function SelLogController()
{
  this.saveCommand   = 'commands/saveSelLog.php';
  this.viewController = new ViewController('selLogFrame');
  this.viewURL = 'views/selLog.php';
  this.clearRequest = new ServerRequest('commands/clearSelLog.php');

  this.clearButton = getElement('clearSelLog');
  this.saveButton = getElement('saveSelLog');
  this.saveAllButton = getElement('saveAllLogsFromSelLogView');
  this.sortField = '';
  this.shadowBox = this.viewController.shadowBox;
  this.init();
}

SelLogController.prototype.init = function init()
{
  this.clearButton.controller = this;
  this.clearButton.action = function ()
  {
    this.controller.promptToClearLog(translate('MSG_SYSTEM_EVENT_LOG'), this.controller);
  }
  this.clearButton.disable();

  this.saveButton.controller = this;
  this.saveButton.action = function ()
  {
    //Frontend.saveDialog.openDialog((translate('MSG_SAVE') + ' ' + translate('MSG_SYSTEM_EVENT_LOG')), 'sel', this.controller);
    this.controller.save();
  }
  this.saveButton.disable();

  this.clearRequest.controller = this;
  this.clearRequest.callback = function ()
  {
    this.controller.refreshFrame();
  }
  this.saveAllButton.controller = this;
  this.saveAllButton.action = function () {
    this.controller.saveAll();
  }
  this.saveAllButton.enable();
}

SelLogController.prototype.refreshFrame = function refreshFrame()
{
  this.clearButton.disable();
  this.saveButton.disable();
  this.saveAllButton.enable();
  this.viewController.setParameter('sortField', this.sortField);
  this.viewController.setURL(this.viewURL);
}

SelLogController.prototype.sortTable = function sortTable(column)
{
  this.sortField = column;
  this.refreshFrame();
}

SelLogController.prototype.promptToClearLog = function promptToClearLog(title)
{
  var controller = this;
  var dialog = Frontend.dialog;
  dialog.toggleBadge(false);
  dialog.setHeader(title);
  dialog.toggleHeader(true);
  dialog.setContent(translate('MSG_CLEAR_LOG_CONFIRMATION'));
  dialog.toggleContent(true);
  dialog.clearButtons();
  dialog.addButton(translate('MSG_OK'), null, function ()
  {
    dialog.hide();
    controller.clearLog();
  });
  dialog.addButton(translate('MSG_CANCEL'), null, function ()
  {
    dialog.hide();
  });
  dialog.toggleButtons(true);
  dialog.show();
}

SelLogController.prototype.clearLog = function clearLog()
{
  this.clearRequest.send();
}

SelLogController.prototype.appendSaveInfo = function appendSaveInfo(request)
{
  request.addVariable('sortField', this.sortField);
}

SelLogController.prototype.save = function save()
{
  var header = (translate('MSG_SAVE') + ' ' + translate('MSG_SYSTEM_EVENT_LOG'));
  if (CONFIG.IS_OFFLINE)
  {
    Frontend.saveDialog.openDialog(header, 'sel', this);
  }
  else
  {
    var query =
    {
      attachment : 1,
      filename   : 'sel',
      sortField  : this.sortField
    }
    Frontend.clientSave(this.saveCommand, query, header);
  }
}

SelLogController.prototype.saveAll = function saveAll() {
  var header = translate('MSG_SAVE_ALL_LOGS');
  if (CONFIG.IS_OFFLINE) {
    Frontend.saveDialog.openDialog(header, 'alllogs', this);
  }
  else {
    var query =
    {
      attachment: 1,
      filename: 'alllogs',
      sortField: this.sortField
    }
    Frontend.clientSave('commands/saveAllLogs.php', query, header);
  }
}
